@@ -1,5 +1,4 @@
-// Copyright (C) 2011 Giovanni Campagna
-// Copyright (C) 2013-2014 Jonas Kümmerlin <rgcjonas@gmail.com>
+// This file is part of the AppIndicator/KStatusNotifierItem GNOME Shell extension
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -29,7 +28,7 @@ const Lang = imports.lang
 const Signals = imports.signals
 
 const DBusMenu = Extension.imports.dbusMenu;
-const IconCache = Extension.imports.iconCache;
+var IconCache = Extension.imports.iconCache;
 const Util = Extension.imports.util;
 const Interfaces = Extension.imports.interfaces;
 
@@ -40,7 +39,7 @@ const SNICategory = {
     HARDWARE: 'Hardware'
 };
 
-const SNIStatus = {
+var SNIStatus = {
     PASSIVE: 'Passive',
     ACTIVE: 'Active',
     NEEDS_ATTENTION: 'NeedsAttention'
@@ -50,7 +49,7 @@ const SNIStatus = {
  * the AppIndicator class serves as a generic container for indicator information and functions common
  * for every displaying implementation (IndicatorMessageSource and IndicatorStatusIcon)
  */
-const AppIndicator = new Lang.Class({
+var AppIndicator = new Lang.Class({
     Name: 'AppIndicator',
 
     _init: function(bus_name, object) {
@@ -216,7 +215,7 @@ const AppIndicator = new Lang.Class({
 });
 Signals.addSignalMethods(AppIndicator.prototype);
 
-const IconActor = new Lang.Class({
+var IconActor = new Lang.Class({
     Name: 'AppIndicatorIconActor',
     Extends: Shell.Stack,
     GTypeName: Util.WORKAROUND_RELOAD_TYPE_REGISTER('AppIndicatorIconActor'),
@@ -228,7 +227,7 @@ const IconActor = new Lang.Class({
         this.height = icon_size * scale_factor
 
         this._indicator     = indicator
-        this._iconSize      = icon_size * scale_factor
+        this._iconSize      = icon_size
         this._iconCache     = new IconCache.IconCache()
 
         this._mainIcon    = new St.Bin()
@@ -336,6 +335,8 @@ const IconActor = new Lang.Class({
     },
 
     _createIconFromPixmap: function(iconSize, iconPixmapArray) {
+        let scale_factor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
+        iconSize = iconSize * scale_factor
         // the pixmap actually is an array of pixmaps with different sizes
         // we use the one that is smaller or equal the iconSize
 
