@@ -1,5 +1,4 @@
-// Copyright (C) 2011 Giovanni Campagna
-// Copyright (C) 2013-2015 Jonas Kümmerlin <rgcjonas@gmail.com>
+// This file is part of the AppIndicator/KStatusNotifierItem GNOME Shell extension
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -668,7 +667,7 @@ const MenuUtils = {
  *
  * Something like a mini-god-object
  */
-const Client = new Lang.Class({
+var Client = new Lang.Class({
     Name: 'DbusMenuClient',
 
     _init: function(busName, path) {
